// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: osmformat.proto
// Protobuf C++ Version: 7.35.0

#include "osmformat.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/io/zero_copy_stream_impl_lite.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
namespace OSMPBF {
class StringTable::_Internal {
 public:
  using HasBits = decltype(::std::declval<StringTable>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(StringTable, _impl_._has_bits_);
};

constexpr StringTable::ParseTableT_ StringTable::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(StringTable, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::StringTable>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated bytes s = 1;
      {::_pbi::TcParser::FastBR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(StringTable, _impl_.s_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated bytes s = 1;
      {PROTOBUF_FIELD_OFFSET(StringTable, _impl_.s_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kBytes | ::_fl::kRepSString)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr StringTable::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        s_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::StringTable,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::StringTable, _impl_.s_)>()
         }
     {}

template <typename>
constexpr StringTable::StringTable(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL StringTable::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) StringTable(arena);
}
constexpr auto StringTable::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(StringTable), alignof(StringTable));
}
constexpr auto StringTable::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &StringTable::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<StringTable>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &StringTable::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<StringTable>(), &StringTable::ByteSizeLong,
              &StringTable::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(StringTable, _impl_._cached_size_),
          true,
      },
      "OSMPBF.StringTable",
  };
}
struct StringTableGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr StringTableGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 StringTable_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(StringTable::InternalGenerateClassData_(
            _default, &StringTable_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<StringTable>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~StringTableGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) StringTable _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<StringTable>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(StringTableGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST StringTableGlobalsTypeInternal StringTable_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* StringTable_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return StringTable_globals_.GetClassData();
#else
  return StringTable_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Info::_Internal {
 public:
  using HasBits = decltype(::std::declval<Info>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Info, _impl_._has_bits_);
};

constexpr Info::ParseTableT_ Info::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Info, _impl_._has_bits_),
      0, // no _extensions_
      6, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967232,  // skipmap
      offsetof(ParseTableT_, field_entries),
      6,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::Info>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // optional int32 version = 1 [default = -1];
      {::_pbi::TcParser::FastV32S1,
       {8, 5, 0,
        PROTOBUF_FIELD_OFFSET(Info, _impl_.version_)}},
      // optional int64 timestamp = 2;
      {::_pbi::TcParser::FastV64S1,
       {16, 0, 0,
        PROTOBUF_FIELD_OFFSET(Info, _impl_.timestamp_)}},
      // optional int64 changeset = 3;
      {::_pbi::TcParser::FastV64S1,
       {24, 1, 0,
        PROTOBUF_FIELD_OFFSET(Info, _impl_.changeset_)}},
      // optional int32 uid = 4;
      {::_pbi::TcParser::FastV32S1,
       {32, 2, 0,
        PROTOBUF_FIELD_OFFSET(Info, _impl_.uid_)}},
      // optional uint32 user_sid = 5;
      {::_pbi::TcParser::FastV32S1,
       {40, 3, 0,
        PROTOBUF_FIELD_OFFSET(Info, _impl_.user_sid_)}},
      // optional bool visible = 6;
      {::_pbi::TcParser::FastV8S1,
       {48, 4, 0,
        PROTOBUF_FIELD_OFFSET(Info, _impl_.visible_)}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // optional int32 version = 1 [default = -1];
      {PROTOBUF_FIELD_OFFSET(Info, _impl_.version_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // optional int64 timestamp = 2;
      {PROTOBUF_FIELD_OFFSET(Info, _impl_.timestamp_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // optional int64 changeset = 3;
      {PROTOBUF_FIELD_OFFSET(Info, _impl_.changeset_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // optional int32 uid = 4;
      {PROTOBUF_FIELD_OFFSET(Info, _impl_.uid_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // optional uint32 user_sid = 5;
      {PROTOBUF_FIELD_OFFSET(Info, _impl_.user_sid_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // optional bool visible = 6;
      {PROTOBUF_FIELD_OFFSET(Info, _impl_.visible_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr Info::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        timestamp_{::int64_t{0}},
        changeset_{::int64_t{0}},
        uid_{0},
        user_sid_{0u},
        visible_{false},
        version_{-1} {}

template <typename>
constexpr Info::Info(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Info::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Info(arena);
}
constexpr auto Info::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Info), alignof(Info));
}
constexpr auto Info::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &Info::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<Info>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Info::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<Info>(), &Info::ByteSizeLong,
              &Info::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Info, _impl_._cached_size_),
          true,
      },
      "OSMPBF.Info",
  };
}
struct InfoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr InfoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Info_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Info::InternalGenerateClassData_(
            _default, &Info_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Info>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~InfoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Info _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Info>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(InfoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST InfoGlobalsTypeInternal Info_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Info_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Info_globals_.GetClassData();
#else
  return Info_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class HeaderBBox::_Internal {
 public:
  using HasBits = decltype(::std::declval<HeaderBBox>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x0000000f) ^ 0x0000000f) != 0;
  }
};

constexpr HeaderBBox::ParseTableT_ HeaderBBox::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_._has_bits_),
      0, // no _extensions_
      4, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967280,  // skipmap
      offsetof(ParseTableT_, field_entries),
      4,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::HeaderBBox>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required sint64 bottom = 4;
      {::_pbi::TcParser::FastZ64S1,
       {32, 3, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.bottom_)}},
      // required sint64 left = 1;
      {::_pbi::TcParser::FastZ64S1,
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.left_)}},
      // required sint64 right = 2;
      {::_pbi::TcParser::FastZ64S1,
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.right_)}},
      // required sint64 top = 3;
      {::_pbi::TcParser::FastZ64S1,
       {24, 2, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.top_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required sint64 left = 1;
      {PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.left_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kSInt64)},
      // required sint64 right = 2;
      {PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.right_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kSInt64)},
      // required sint64 top = 3;
      {PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.top_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kSInt64)},
      // required sint64 bottom = 4;
      {PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.bottom_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kSInt64)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr HeaderBBox::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        left_{::int64_t{0}},
        right_{::int64_t{0}},
        top_{::int64_t{0}},
        bottom_{::int64_t{0}} {}

template <typename>
constexpr HeaderBBox::HeaderBBox(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL HeaderBBox::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) HeaderBBox(arena);
}
constexpr auto HeaderBBox::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(HeaderBBox), alignof(HeaderBBox));
}
constexpr auto HeaderBBox::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          HeaderBBox::IsInitializedImpl,
          &HeaderBBox::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<HeaderBBox>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &HeaderBBox::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<HeaderBBox>(), &HeaderBBox::ByteSizeLong,
              &HeaderBBox::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_._cached_size_),
          true,
      },
      "OSMPBF.HeaderBBox",
  };
}
struct HeaderBBoxGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr HeaderBBoxGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 HeaderBBox_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(HeaderBBox::InternalGenerateClassData_(
            _default, &HeaderBBox_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<HeaderBBox>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~HeaderBBoxGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) HeaderBBox _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<HeaderBBox>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(HeaderBBoxGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST HeaderBBoxGlobalsTypeInternal HeaderBBox_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* HeaderBBox_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return HeaderBBox_globals_.GetClassData();
#else
  return HeaderBBox_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class DenseInfo::_Internal {
 public:
  using HasBits = decltype(::std::declval<DenseInfo>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_._has_bits_);
};

constexpr DenseInfo::ParseTableT_ DenseInfo::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_._has_bits_),
      0, // no _extensions_
      6, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967232,  // skipmap
      offsetof(ParseTableT_, field_entries),
      6,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::DenseInfo>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // repeated int32 version = 1 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.version_)}},
      // repeated sint64 timestamp = 2 [packed = true];
      {::_pbi::TcParser::FastZ64P1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.timestamp_)}},
      // repeated sint64 changeset = 3 [packed = true];
      {::_pbi::TcParser::FastZ64P1,
       {26, 2, 0,
        PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.changeset_)}},
      // repeated sint32 uid = 4 [packed = true];
      {::_pbi::TcParser::FastZ32P1,
       {34, 3, 0,
        PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.uid_)}},
      // repeated sint32 user_sid = 5 [packed = true];
      {::_pbi::TcParser::FastZ32P1,
       {42, 4, 0,
        PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.user_sid_)}},
      // repeated bool visible = 6 [packed = true];
      {::_pbi::TcParser::FastV8P1,
       {50, 5, 0,
        PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.visible_)}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated int32 version = 1 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.version_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedInt32)},
      // repeated sint64 timestamp = 2 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.timestamp_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt64)},
      // repeated sint64 changeset = 3 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.changeset_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt64)},
      // repeated sint32 uid = 4 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.uid_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt32)},
      // repeated sint32 user_sid = 5 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.user_sid_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt32)},
      // repeated bool visible = 6 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_.visible_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedBool)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr DenseInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        version_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.version_)>()
         }
        ,
        _version_cached_byte_size_{0},
        timestamp_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.timestamp_)>()
         }
        ,
        _timestamp_cached_byte_size_{0},
        changeset_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.changeset_)>()
         }
        ,
        _changeset_cached_byte_size_{0},
        uid_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.uid_)>()
         }
        ,
        _uid_cached_byte_size_{0},
        user_sid_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.user_sid_)>()
         }
        ,
        _user_sid_cached_byte_size_{0},
        visible_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.visible_)>()
         }
     {}

template <typename>
constexpr DenseInfo::DenseInfo(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL DenseInfo::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) DenseInfo(arena);
}
constexpr auto DenseInfo::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(DenseInfo), alignof(DenseInfo));
}
constexpr auto DenseInfo::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &DenseInfo::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<DenseInfo>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &DenseInfo::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<DenseInfo>(), &DenseInfo::ByteSizeLong,
              &DenseInfo::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(DenseInfo, _impl_._cached_size_),
          true,
      },
      "OSMPBF.DenseInfo",
  };
}
struct DenseInfoGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DenseInfoGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 DenseInfo_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(DenseInfo::InternalGenerateClassData_(
            _default, &DenseInfo_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<DenseInfo>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DenseInfoGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) DenseInfo _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<DenseInfo>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DenseInfoGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DenseInfoGlobalsTypeInternal DenseInfo_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* DenseInfo_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return DenseInfo_globals_.GetClassData();
#else
  return DenseInfo_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ChangeSet::_Internal {
 public:
  using HasBits = decltype(::std::declval<ChangeSet>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ChangeSet, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000001) ^ 0x00000001) != 0;
  }
};

constexpr ChangeSet::ParseTableT_ ChangeSet::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ChangeSet, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::ChangeSet>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required int64 id = 1;
      {::_pbi::TcParser::FastV64S1,
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(ChangeSet, _impl_.id_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required int64 id = 1;
      {PROTOBUF_FIELD_OFFSET(ChangeSet, _impl_.id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr ChangeSet::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        id_{::int64_t{0}} {}

template <typename>
constexpr ChangeSet::ChangeSet(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ChangeSet::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ChangeSet(arena);
}
constexpr auto ChangeSet::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ChangeSet), alignof(ChangeSet));
}
constexpr auto ChangeSet::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          ChangeSet::IsInitializedImpl,
          &ChangeSet::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<ChangeSet>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ChangeSet::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<ChangeSet>(), &ChangeSet::ByteSizeLong,
              &ChangeSet::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ChangeSet, _impl_._cached_size_),
          true,
      },
      "OSMPBF.ChangeSet",
  };
}
struct ChangeSetGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ChangeSetGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ChangeSet_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ChangeSet::InternalGenerateClassData_(
            _default, &ChangeSet_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ChangeSet>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ChangeSetGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ChangeSet _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ChangeSet>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ChangeSetGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ChangeSetGlobalsTypeInternal ChangeSet_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ChangeSet_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ChangeSet_globals_.GetClassData();
#else
  return ChangeSet_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Way::_Internal {
 public:
  using HasBits = decltype(::std::declval<Way>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Way, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000010) ^ 0x00000010) != 0;
  }
};

constexpr Way::ParseTableT_ Way::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Way, _impl_._has_bits_),
      0, // no _extensions_
      8, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967152,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::Way>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated sint64 refs = 8 [packed = true];
      {::_pbi::TcParser::FastZ64P1,
       {66, 2, 0,
        PROTOBUF_FIELD_OFFSET(Way, _impl_.refs_)}},
      // required int64 id = 1;
      {::_pbi::TcParser::FastV64S1,
       {8, 4, 0,
        PROTOBUF_FIELD_OFFSET(Way, _impl_.id_)}},
      // repeated uint32 keys = 2 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {18, 0, 0,
        PROTOBUF_FIELD_OFFSET(Way, _impl_.keys_)}},
      // repeated uint32 vals = 3 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(Way, _impl_.vals_)}},
      // optional .OSMPBF.Info info = 4;
      {::_pbi::TcParser::FastMtS1,
       {34, 3, 0,
        PROTOBUF_FIELD_OFFSET(Way, _impl_.info_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // required int64 id = 1;
      {PROTOBUF_FIELD_OFFSET(Way, _impl_.id_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // repeated uint32 keys = 2 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Way, _impl_.keys_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedUInt32)},
      // repeated uint32 vals = 3 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Way, _impl_.vals_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedUInt32)},
      // optional .OSMPBF.Info info = 4;
      {PROTOBUF_FIELD_OFFSET(Way, _impl_.info_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated sint64 refs = 8 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Way, _impl_.refs_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt64)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::Info>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::Info_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr Way::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        keys_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Way,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.keys_)>()
         }
        ,
        _keys_cached_byte_size_{0},
        vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Way,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.vals_)>()
         }
        ,
        _vals_cached_byte_size_{0},
        refs_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Way,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.refs_)>()
         }
        ,
        _refs_cached_byte_size_{0},
        info_{nullptr},
        id_{::int64_t{0}} {}

template <typename>
constexpr Way::Way(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Way::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Way(arena);
}
constexpr auto Way::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Way), alignof(Way));
}
constexpr auto Way::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          Way::IsInitializedImpl,
          &Way::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<Way>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Way::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<Way>(), &Way::ByteSizeLong,
              &Way::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Way, _impl_._cached_size_),
          true,
      },
      "OSMPBF.Way",
  };
}
struct WayGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr WayGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Way_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Way::InternalGenerateClassData_(
            _default, &Way_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Way>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~WayGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Way _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Way>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(WayGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST WayGlobalsTypeInternal Way_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Way_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Way_globals_.GetClassData();
#else
  return Way_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Relation::_Internal {
 public:
  using HasBits = decltype(::std::declval<Relation>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Relation, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000010) ^ 0x00000010) != 0;
  }
};

constexpr Relation::ParseTableT_ Relation::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Relation, _impl_._has_bits_),
      0, // no _extensions_
      10, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294966384,  // skipmap
      offsetof(ParseTableT_, field_entries),
      7,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::Relation>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated int32 roles_sid = 8 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {66, 2, 0,
        PROTOBUF_FIELD_OFFSET(Relation, _impl_.roles_sid_)}},
      // required int64 id = 1;
      {::_pbi::TcParser::FastV64S1,
       {8, 4, 0,
        PROTOBUF_FIELD_OFFSET(Relation, _impl_.id_)}},
      // repeated uint32 keys = 2 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {18, 0, 0,
        PROTOBUF_FIELD_OFFSET(Relation, _impl_.keys_)}},
      // repeated uint32 vals = 3 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(Relation, _impl_.vals_)}},
      // optional .OSMPBF.Info info = 4;
      {::_pbi::TcParser::FastMtS1,
       {34, 3, 0,
        PROTOBUF_FIELD_OFFSET(Relation, _impl_.info_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // required int64 id = 1;
      {PROTOBUF_FIELD_OFFSET(Relation, _impl_.id_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // repeated uint32 keys = 2 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Relation, _impl_.keys_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedUInt32)},
      // repeated uint32 vals = 3 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Relation, _impl_.vals_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedUInt32)},
      // optional .OSMPBF.Info info = 4;
      {PROTOBUF_FIELD_OFFSET(Relation, _impl_.info_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated int32 roles_sid = 8 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Relation, _impl_.roles_sid_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedInt32)},
      // repeated sint64 memids = 9 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Relation, _impl_.memids_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt64)},
      // repeated .OSMPBF.Relation.MemberType types = 10 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Relation, _impl_.types_), _Internal::kHasBitsOffset + 6, 1, (0 | ::_fl::kFcRepeated | ::_fl::kPackedEnumRange)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::Info>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::Info_globals_},
        #endif
        {0, 2},
    }},
    {{
    }},
  };
}


inline constexpr Relation::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        keys_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.keys_)>()
         }
        ,
        _keys_cached_byte_size_{0},
        vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.vals_)>()
         }
        ,
        _vals_cached_byte_size_{0},
        roles_sid_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.roles_sid_)>()
         }
        ,
        _roles_sid_cached_byte_size_{0},
        info_{nullptr},
        id_{::int64_t{0}},
        memids_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.memids_)>()
         }
        ,
        _memids_cached_byte_size_{0},
        types_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.types_)>()
         }
        ,
        _types_cached_byte_size_{0} {}

template <typename>
constexpr Relation::Relation(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Relation::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Relation(arena);
}
constexpr auto Relation::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Relation), alignof(Relation));
}
constexpr auto Relation::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          Relation::IsInitializedImpl,
          &Relation::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<Relation>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Relation::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<Relation>(), &Relation::ByteSizeLong,
              &Relation::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Relation, _impl_._cached_size_),
          true,
      },
      "OSMPBF.Relation",
  };
}
struct RelationGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr RelationGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Relation_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Relation::InternalGenerateClassData_(
            _default, &Relation_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Relation>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~RelationGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Relation _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Relation>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(RelationGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST RelationGlobalsTypeInternal Relation_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Relation_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Relation_globals_.GetClassData();
#else
  return Relation_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Node::_Internal {
 public:
  using HasBits = decltype(::std::declval<Node>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Node, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000038) ^ 0x00000038) != 0;
  }
};

constexpr Node::ParseTableT_ Node::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Node, _impl_._has_bits_),
      0, // no _extensions_
      9, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294966896,  // skipmap
      offsetof(ParseTableT_, field_entries),
      6,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::Node>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required sint64 lat = 8;
      {::_pbi::TcParser::FastZ64S1,
       {64, 4, 0,
        PROTOBUF_FIELD_OFFSET(Node, _impl_.lat_)}},
      // required sint64 id = 1;
      {::_pbi::TcParser::FastZ64S1,
       {8, 3, 0,
        PROTOBUF_FIELD_OFFSET(Node, _impl_.id_)}},
      // repeated uint32 keys = 2 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {18, 0, 0,
        PROTOBUF_FIELD_OFFSET(Node, _impl_.keys_)}},
      // repeated uint32 vals = 3 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(Node, _impl_.vals_)}},
      // optional .OSMPBF.Info info = 4;
      {::_pbi::TcParser::FastMtS1,
       {34, 2, 0,
        PROTOBUF_FIELD_OFFSET(Node, _impl_.info_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // required sint64 id = 1;
      {PROTOBUF_FIELD_OFFSET(Node, _impl_.id_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kSInt64)},
      // repeated uint32 keys = 2 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Node, _impl_.keys_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedUInt32)},
      // repeated uint32 vals = 3 [packed = true];
      {PROTOBUF_FIELD_OFFSET(Node, _impl_.vals_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedUInt32)},
      // optional .OSMPBF.Info info = 4;
      {PROTOBUF_FIELD_OFFSET(Node, _impl_.info_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // required sint64 lat = 8;
      {PROTOBUF_FIELD_OFFSET(Node, _impl_.lat_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kSInt64)},
      // required sint64 lon = 9;
      {PROTOBUF_FIELD_OFFSET(Node, _impl_.lon_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kSInt64)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::Info>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::Info_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr Node::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        keys_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Node,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Node, _impl_.keys_)>()
         }
        ,
        _keys_cached_byte_size_{0},
        vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Node,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Node, _impl_.vals_)>()
         }
        ,
        _vals_cached_byte_size_{0},
        info_{nullptr},
        id_{::int64_t{0}},
        lat_{::int64_t{0}},
        lon_{::int64_t{0}} {}

template <typename>
constexpr Node::Node(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Node::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Node(arena);
}
constexpr auto Node::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Node), alignof(Node));
}
constexpr auto Node::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          Node::IsInitializedImpl,
          &Node::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<Node>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Node::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<Node>(), &Node::ByteSizeLong,
              &Node::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Node, _impl_._cached_size_),
          true,
      },
      "OSMPBF.Node",
  };
}
struct NodeGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr NodeGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Node_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Node::InternalGenerateClassData_(
            _default, &Node_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Node>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~NodeGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Node _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Node>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(NodeGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST NodeGlobalsTypeInternal Node_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Node_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Node_globals_.GetClassData();
#else
  return Node_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class HeaderBlock::_Internal {
 public:
  using HasBits = decltype(::std::declval<HeaderBlock>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_._has_bits_);
};

constexpr HeaderBlock::ParseTableT_ HeaderBlock::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_._has_bits_),
      0, // no _extensions_
      34, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      2147385318,  // skipmap
      offsetof(ParseTableT_, field_entries),
      8,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::HeaderBlock>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // optional string writingprogram = 16;
      {::_pbi::TcParser::FastBS2,
       {386, 2, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.writingprogram_)}},
      // optional .OSMPBF.HeaderBBox bbox = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 5, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.bbox_)}},
      // optional string osmosis_replication_base_url = 34;
      {::_pbi::TcParser::FastBS2,
       {658, 4, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.osmosis_replication_base_url_)}},
      {::_pbi::TcParser::MiniParse, {}},
      // repeated string required_features = 4;
      {::_pbi::TcParser::FastBR1,
       {34, 0, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.required_features_)}},
      // repeated string optional_features = 5;
      {::_pbi::TcParser::FastBR1,
       {42, 1, 0,
        PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.optional_features_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      33, 0, 1,
      65532, 6,
      65535, 65535
    }}, {{
      // optional .OSMPBF.HeaderBBox bbox = 1;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.bbox_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated string required_features = 4;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.required_features_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kBytes | ::_fl::kRepSString)},
      // repeated string optional_features = 5;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.optional_features_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kBytes | ::_fl::kRepSString)},
      // optional string writingprogram = 16;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.writingprogram_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
      // optional string source = 17;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.source_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
      // optional int64 osmosis_replication_timestamp = 32;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.osmosis_replication_timestamp_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // optional int64 osmosis_replication_sequence_number = 33;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.osmosis_replication_sequence_number_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // optional string osmosis_replication_base_url = 34;
      {PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.osmosis_replication_base_url_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::HeaderBBox>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::HeaderBBox_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr HeaderBlock::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        required_features_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::HeaderBlock,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::HeaderBlock, _impl_.required_features_)>()
         }
        ,
        optional_features_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::HeaderBlock,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::HeaderBlock, _impl_.optional_features_)>()
         }
        ,
        writingprogram_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        source_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        osmosis_replication_base_url_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        bbox_{nullptr},
        osmosis_replication_timestamp_{::int64_t{0}},
        osmosis_replication_sequence_number_{::int64_t{0}} {}

template <typename>
constexpr HeaderBlock::HeaderBlock(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL HeaderBlock::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) HeaderBlock(arena);
}
constexpr auto HeaderBlock::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(HeaderBlock), alignof(HeaderBlock));
}
constexpr auto HeaderBlock::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          HeaderBlock::IsInitializedImpl,
          &HeaderBlock::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<HeaderBlock>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &HeaderBlock::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<HeaderBlock>(), &HeaderBlock::ByteSizeLong,
              &HeaderBlock::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_._cached_size_),
          true,
      },
      "OSMPBF.HeaderBlock",
  };
}
struct HeaderBlockGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr HeaderBlockGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 HeaderBlock_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(HeaderBlock::InternalGenerateClassData_(
            _default, &HeaderBlock_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<HeaderBlock>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~HeaderBlockGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) HeaderBlock _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<HeaderBlock>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(HeaderBlockGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST HeaderBlockGlobalsTypeInternal HeaderBlock_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* HeaderBlock_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return HeaderBlock_globals_.GetClassData();
#else
  return HeaderBlock_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class DenseNodes::_Internal {
 public:
  using HasBits = decltype(::std::declval<DenseNodes>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_._has_bits_);
};

constexpr DenseNodes::ParseTableT_ DenseNodes::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_._has_bits_),
      0, // no _extensions_
      10, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294966382,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::DenseNodes>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated sint64 lat = 8 [packed = true];
      {::_pbi::TcParser::FastZ64P1,
       {66, 1, 0,
        PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.lat_)}},
      // repeated sint64 id = 1 [packed = true];
      {::_pbi::TcParser::FastZ64P1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.id_)}},
      // repeated int32 keys_vals = 10 [packed = true];
      {::_pbi::TcParser::FastV32P1,
       {82, 2, 0,
        PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.keys_vals_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      // optional .OSMPBF.DenseInfo denseinfo = 5;
      {::_pbi::TcParser::FastMtS1,
       {42, 3, 0,
        PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.denseinfo_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated sint64 id = 1 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt64)},
      // optional .OSMPBF.DenseInfo denseinfo = 5;
      {PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.denseinfo_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated sint64 lat = 8 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.lat_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt64)},
      // repeated sint64 lon = 9 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.lon_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedSInt64)},
      // repeated int32 keys_vals = 10 [packed = true];
      {PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_.keys_vals_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcRepeated | ::_fl::kPackedInt32)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::DenseInfo>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::DenseInfo_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr DenseNodes::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        id_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.id_)>()
         }
        ,
        _id_cached_byte_size_{0},
        lat_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.lat_)>()
         }
        ,
        _lat_cached_byte_size_{0},
        keys_vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.keys_vals_)>()
         }
        ,
        _keys_vals_cached_byte_size_{0},
        denseinfo_{nullptr},
        lon_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.lon_)>()
         }
        ,
        _lon_cached_byte_size_{0} {}

template <typename>
constexpr DenseNodes::DenseNodes(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL DenseNodes::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) DenseNodes(arena);
}
constexpr auto DenseNodes::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(DenseNodes), alignof(DenseNodes));
}
constexpr auto DenseNodes::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &DenseNodes::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<DenseNodes>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &DenseNodes::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<DenseNodes>(), &DenseNodes::ByteSizeLong,
              &DenseNodes::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(DenseNodes, _impl_._cached_size_),
          true,
      },
      "OSMPBF.DenseNodes",
  };
}
struct DenseNodesGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DenseNodesGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 DenseNodes_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(DenseNodes::InternalGenerateClassData_(
            _default, &DenseNodes_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<DenseNodes>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DenseNodesGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) DenseNodes _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<DenseNodes>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DenseNodesGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DenseNodesGlobalsTypeInternal DenseNodes_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* DenseNodes_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return DenseNodes_globals_.GetClassData();
#else
  return DenseNodes_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class PrimitiveGroup::_Internal {
 public:
  using HasBits = decltype(::std::declval<PrimitiveGroup>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_._has_bits_);
};

constexpr PrimitiveGroup::ParseTableT_ PrimitiveGroup::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_._has_bits_),
      0, // no _extensions_
      5, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967264,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      5,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::PrimitiveGroup>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // repeated .OSMPBF.Node nodes = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.nodes_)}},
      // optional .OSMPBF.DenseNodes dense = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 4, 1,
        PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.dense_)}},
      // repeated .OSMPBF.Way ways = 3;
      {::_pbi::TcParser::FastMtR1,
       {26, 1, 2,
        PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.ways_)}},
      // repeated .OSMPBF.Relation relations = 4;
      {::_pbi::TcParser::FastMtR1,
       {34, 2, 3,
        PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.relations_)}},
      // repeated .OSMPBF.ChangeSet changesets = 5;
      {::_pbi::TcParser::FastMtR1,
       {42, 3, 4,
        PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.changesets_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .OSMPBF.Node nodes = 1;
      {PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.nodes_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // optional .OSMPBF.DenseNodes dense = 2;
      {PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.dense_), _Internal::kHasBitsOffset + 4, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .OSMPBF.Way ways = 3;
      {PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.ways_), _Internal::kHasBitsOffset + 1, 2, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .OSMPBF.Relation relations = 4;
      {PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.relations_), _Internal::kHasBitsOffset + 2, 3, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .OSMPBF.ChangeSet changesets = 5;
      {PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_.changesets_), _Internal::kHasBitsOffset + 3, 4, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::Node>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::Node_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::DenseNodes>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::DenseNodes_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::Way>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::Way_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::Relation>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::Relation_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::ChangeSet>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::ChangeSet_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr PrimitiveGroup::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        nodes_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.nodes_)>()
         }
        ,
        ways_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.ways_)>()
         }
        ,
        relations_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.relations_)>()
         }
        ,
        changesets_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.changesets_)>()
         }
        ,
        dense_{nullptr} {}

template <typename>
constexpr PrimitiveGroup::PrimitiveGroup(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL PrimitiveGroup::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) PrimitiveGroup(arena);
}
constexpr auto PrimitiveGroup::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(PrimitiveGroup), alignof(PrimitiveGroup));
}
constexpr auto PrimitiveGroup::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          PrimitiveGroup::IsInitializedImpl,
          &PrimitiveGroup::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<PrimitiveGroup>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &PrimitiveGroup::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<PrimitiveGroup>(), &PrimitiveGroup::ByteSizeLong,
              &PrimitiveGroup::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(PrimitiveGroup, _impl_._cached_size_),
          true,
      },
      "OSMPBF.PrimitiveGroup",
  };
}
struct PrimitiveGroupGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr PrimitiveGroupGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 PrimitiveGroup_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(PrimitiveGroup::InternalGenerateClassData_(
            _default, &PrimitiveGroup_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<PrimitiveGroup>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~PrimitiveGroupGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) PrimitiveGroup _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<PrimitiveGroup>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(PrimitiveGroupGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST PrimitiveGroupGlobalsTypeInternal PrimitiveGroup_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* PrimitiveGroup_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return PrimitiveGroup_globals_.GetClassData();
#else
  return PrimitiveGroup_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class PrimitiveBlock::_Internal {
 public:
  using HasBits = decltype(::std::declval<PrimitiveBlock>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000002) ^ 0x00000002) != 0;
  }
};

constexpr PrimitiveBlock::ParseTableT_ PrimitiveBlock::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_._has_bits_),
      0, // no _extensions_
      20, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4293984252,  // skipmap
      offsetof(ParseTableT_, field_entries),
      6,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallbackLite,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::OSMPBF::PrimitiveBlock>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // optional int64 lon_offset = 20 [default = 0];
      {::_pbi::TcParser::FastV64S2,
       {416, 3, 0,
        PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.lon_offset_)}},
      // required .OSMPBF.StringTable stringtable = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 1, 0,
        PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.stringtable_)}},
      // repeated .OSMPBF.PrimitiveGroup primitivegroup = 2;
      {::_pbi::TcParser::FastMtR1,
       {18, 0, 1,
        PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.primitivegroup_)}},
      // optional int64 lat_offset = 19 [default = 0];
      {::_pbi::TcParser::FastV64S2,
       {408, 2, 0,
        PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.lat_offset_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required .OSMPBF.StringTable stringtable = 1;
      {PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.stringtable_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .OSMPBF.PrimitiveGroup primitivegroup = 2;
      {PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.primitivegroup_), _Internal::kHasBitsOffset + 0, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // optional int32 granularity = 17 [default = 100];
      {PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.granularity_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // optional int32 date_granularity = 18 [default = 1000];
      {PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.date_granularity_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // optional int64 lat_offset = 19 [default = 0];
      {PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.lat_offset_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // optional int64 lon_offset = 20 [default = 0];
      {PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.lon_offset_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::StringTable>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::StringTable_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::OSMPBF::PrimitiveGroup>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::OSMPBF::PrimitiveGroup_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr PrimitiveBlock::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        primitivegroup_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveBlock,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveBlock, _impl_.primitivegroup_)>()
         }
        ,
        stringtable_{nullptr},
        lat_offset_{::int64_t{0}},
        lon_offset_{::int64_t{0}},
        granularity_{100},
        date_granularity_{1000} {}

template <typename>
constexpr PrimitiveBlock::PrimitiveBlock(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::MessageLite(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL PrimitiveBlock::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) PrimitiveBlock(arena);
}
constexpr auto PrimitiveBlock::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(PrimitiveBlock), alignof(PrimitiveBlock));
}
constexpr auto PrimitiveBlock::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataLite{
      {
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          PrimitiveBlock::IsInitializedImpl,
          &PrimitiveBlock::MergeImpl,
          ::google::protobuf::MessageLite::GetNewImpl<PrimitiveBlock>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &PrimitiveBlock::SharedDtor,
          ::google::protobuf::MessageLite::GetClearImpl<PrimitiveBlock>(), &PrimitiveBlock::ByteSizeLong,
              &PrimitiveBlock::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_._cached_size_),
          true,
      },
      "OSMPBF.PrimitiveBlock",
  };
}
struct PrimitiveBlockGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr PrimitiveBlockGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 PrimitiveBlock_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(PrimitiveBlock::InternalGenerateClassData_(
            _default, &PrimitiveBlock_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<PrimitiveBlock>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~PrimitiveBlockGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) PrimitiveBlock _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<PrimitiveBlock>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(PrimitiveBlockGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST PrimitiveBlockGlobalsTypeInternal PrimitiveBlock_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* PrimitiveBlock_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return PrimitiveBlock_globals_.GetClassData();
#else
  return PrimitiveBlock_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace OSMPBF
namespace OSMPBF {
PROTOBUF_CONSTINIT const uint32_t Relation_MemberType_internal_data_[] = {
    196608u, 0u, };
static const char Relation_MemberType_names[] = {
    "NODE"
    "RELATION"
    "WAY"
};

static const ::google::protobuf::internal::EnumEntry Relation_MemberType_entries[] = {
    {{&Relation_MemberType_names[0], 4}, 0},
    {{&Relation_MemberType_names[4], 8}, 2},
    {{&Relation_MemberType_names[12], 3}, 1},
};

static const int Relation_MemberType_entries_by_number[] = {
    0,  // 0 -> NODE
    2,  // 1 -> WAY
    1,  // 2 -> RELATION
};

[[nodiscard]] bool Relation_MemberType_Parse(::absl::string_view name,
                                  Relation_MemberType* PROTOBUF_NONNULL value) {
  int int_value;
  bool success = ::google::protobuf::internal::LookUpEnumValue(
      Relation_MemberType_entries, 3, name, &int_value);
  if (success) {
    *value = static_cast<Relation_MemberType>(int_value);
  }
  return success;
}
static ::google::protobuf::internal::ExplicitlyConstructed<::std::string>
    Relation_MemberType_strings[3] = {};

[[nodiscard]] const ::std::string& Relation_MemberType_Name(Relation_MemberType value) {
  static const bool kDummy = ::google::protobuf::internal::InitializeEnumStrings(
      Relation_MemberType_entries, Relation_MemberType_entries_by_number, 3,
      Relation_MemberType_strings);
  (void)kDummy;

  int idx = ::google::protobuf::internal::LookUpEnumName(Relation_MemberType_entries,
                                  Relation_MemberType_entries_by_number,
                                  3, value);
  return idx == -1 ? ::google::protobuf::internal::GetEmptyString() : Relation_MemberType_strings[idx].get();
}
// ===================================================================

HeaderBlock::HeaderBlock(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, HeaderBlock_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.HeaderBlock)
}
PROTOBUF_NDEBUG_INLINE HeaderBlock::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::HeaderBlock& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        required_features_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::HeaderBlock,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::HeaderBlock, _impl_.required_features_)>()
          , from.required_features_
        }
        ,
        optional_features_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::HeaderBlock,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::HeaderBlock, _impl_.optional_features_)>()
          , from.optional_features_
        }
        ,
        writingprogram_(arena, from.writingprogram_),
        source_(arena, from.source_),
        osmosis_replication_base_url_(arena, from.osmosis_replication_base_url_) {}

HeaderBlock::HeaderBlock(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const HeaderBlock& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, HeaderBlock_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  HeaderBlock* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.bbox_ = (CheckHasBit(cached_has_bits, 0x00000020U))
                ? ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.bbox_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, osmosis_replication_timestamp_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, osmosis_replication_timestamp_),
           offsetof(Impl_, osmosis_replication_sequence_number_) -
               offsetof(Impl_, osmosis_replication_timestamp_) +
               sizeof(Impl_::osmosis_replication_sequence_number_));

  // @@protoc_insertion_point(copy_constructor:OSMPBF.HeaderBlock)
}
PROTOBUF_NDEBUG_INLINE HeaderBlock::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        required_features_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::HeaderBlock,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::HeaderBlock, _impl_.required_features_)>()
         }
        ,
        optional_features_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::HeaderBlock,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::HeaderBlock, _impl_.optional_features_)>()
         }
        ,
        writingprogram_(arena),
        source_(arena),
        osmosis_replication_base_url_(arena) {}

inline void HeaderBlock::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, bbox_),
           0,
           offsetof(Impl_, osmosis_replication_sequence_number_) -
               offsetof(Impl_, bbox_) +
               sizeof(Impl_::osmosis_replication_sequence_number_));
}
HeaderBlock::~HeaderBlock() {
  // @@protoc_insertion_point(destructor:OSMPBF.HeaderBlock)
  SharedDtor(*this);
}
inline void HeaderBlock::SharedDtor(MessageLite& self) {
  HeaderBlock& this_ = static_cast<HeaderBlock&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.writingprogram_.Destroy();
  this_._impl_.source_.Destroy();
  this_._impl_.osmosis_replication_base_url_.Destroy();
  delete this_._impl_.bbox_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite HeaderBlock_class_data_ =
    HeaderBlock::InternalGenerateClassData_(HeaderBlock_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
HeaderBlock::GetClassData() const {
  return HeaderBlock_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
HeaderBlock::GetClassData() const {
  return HeaderBlock_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const HeaderBlock::ParseTableT_
    HeaderBlock::_table_ =
        HeaderBlock::InternalGenerateParseTable_(HeaderBlock_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void HeaderBlock::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.HeaderBlock)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.required_features_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.optional_features_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.writingprogram_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.source_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.osmosis_replication_base_url_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(_impl_.bbox_ != nullptr);
      _impl_.bbox_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000c0U)) {
    ::memset(&_impl_.osmosis_replication_timestamp_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.osmosis_replication_sequence_number_) -
        reinterpret_cast<char*>(&_impl_.osmosis_replication_timestamp_)) + sizeof(_impl_.osmosis_replication_sequence_number_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL HeaderBlock::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const HeaderBlock& this_ = static_cast<const HeaderBlock&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL HeaderBlock::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const HeaderBlock& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.HeaderBlock)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // optional .OSMPBF.HeaderBBox bbox = 1;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.bbox_, this_._impl_.bbox_->GetCachedSize(), target,
        stream);
  }

  // repeated string required_features = 4;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (int i = 0, n = this_._internal_required_features_size(); i < n; ++i) {
      const auto& s = this_._internal_required_features().Get(i);
      target = stream->WriteString(4, s, target);
    }
  }

  // repeated string optional_features = 5;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    for (int i = 0, n = this_._internal_optional_features_size(); i < n; ++i) {
      const auto& s = this_._internal_optional_features().Get(i);
      target = stream->WriteString(5, s, target);
    }
  }

  // optional string writingprogram = 16;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    const ::std::string& _s = this_._internal_writingprogram();
    target = stream->WriteStringMaybeAliased(16, _s, target);
  }

  // optional string source = 17;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    const ::std::string& _s = this_._internal_source();
    target = stream->WriteStringMaybeAliased(17, _s, target);
  }

  // optional int64 osmosis_replication_timestamp = 32;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteInt64ToArray(
        32, this_._internal_osmosis_replication_timestamp(), target);
  }

  // optional int64 osmosis_replication_sequence_number = 33;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteInt64ToArray(
        33, this_._internal_osmosis_replication_sequence_number(), target);
  }

  // optional string osmosis_replication_base_url = 34;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    const ::std::string& _s = this_._internal_osmosis_replication_base_url();
    target = stream->WriteStringMaybeAliased(34, _s, target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.HeaderBlock)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t HeaderBlock::ByteSizeLong(const MessageLite& base) {
  const HeaderBlock& this_ = static_cast<const HeaderBlock&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t HeaderBlock::ByteSizeLong() const {
  const HeaderBlock& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.HeaderBlock)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // repeated string required_features = 4;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_required_features().size());
      for (int i = 0, n = this_._internal_required_features().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
            this_._internal_required_features().Get(i));
      }
    }
    // repeated string optional_features = 5;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_optional_features().size());
      for (int i = 0, n = this_._internal_optional_features().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
            this_._internal_optional_features().Get(i));
      }
    }
    // optional string writingprogram = 16;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_writingprogram());
    }
    // optional string source = 17;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_source());
    }
    // optional string osmosis_replication_base_url = 34;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_osmosis_replication_base_url());
    }
    // optional .OSMPBF.HeaderBBox bbox = 1;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.bbox_);
    }
    // optional int64 osmosis_replication_timestamp = 32;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      total_size += 2 + ::_pbi::WireFormatLite::Int64Size(
                                      this_._internal_osmosis_replication_timestamp());
    }
    // optional int64 osmosis_replication_sequence_number = 33;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      total_size += 2 + ::_pbi::WireFormatLite::Int64Size(
                                      this_._internal_osmosis_replication_sequence_number());
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void HeaderBlock::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<HeaderBlock*>(&to_msg);
  auto& from = static_cast<const HeaderBlock&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.HeaderBlock)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_required_features()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_required_features());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_optional_features()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_optional_features());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_set_writingprogram(from._internal_writingprogram());
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_internal_set_source(from._internal_source());
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_internal_set_osmosis_replication_base_url(from._internal_osmosis_replication_base_url());
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(from._impl_.bbox_ != nullptr);
      if (_this->_impl_.bbox_ == nullptr) {
        _this->_impl_.bbox_ = ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.bbox_);
      } else {
        _this->_impl_.bbox_->MergeFrom(*from._impl_.bbox_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _this->_impl_.osmosis_replication_timestamp_ = from._impl_.osmosis_replication_timestamp_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _this->_impl_.osmosis_replication_sequence_number_ = from._impl_.osmosis_replication_sequence_number_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void HeaderBlock::CopyFrom(const HeaderBlock& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.HeaderBlock)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool HeaderBlock::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const HeaderBlock&>(msg);
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000020U)) {
    if (!this_._impl_.bbox_->IsInitialized()) return false;
  }
  return true;
}

void HeaderBlock::InternalSwap(HeaderBlock* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.required_features_.InternalSwap(&other->_impl_.required_features_);
  _impl_.optional_features_.InternalSwap(&other->_impl_.optional_features_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.writingprogram_, &other->_impl_.writingprogram_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.source_, &other->_impl_.source_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.osmosis_replication_base_url_, &other->_impl_.osmosis_replication_base_url_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.osmosis_replication_sequence_number_)
      + sizeof(HeaderBlock::_impl_.osmosis_replication_sequence_number_)
      - PROTOBUF_FIELD_OFFSET(HeaderBlock, _impl_.bbox_)>(
          reinterpret_cast<char*>(&_impl_.bbox_),
          reinterpret_cast<char*>(&other->_impl_.bbox_));
}

// ===================================================================

HeaderBBox::HeaderBBox(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, HeaderBBox_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.HeaderBBox)
}
HeaderBBox::HeaderBBox(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const HeaderBBox& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, HeaderBBox_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE HeaderBBox::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void HeaderBBox::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, left_),
           0,
           offsetof(Impl_, bottom_) -
               offsetof(Impl_, left_) +
               sizeof(Impl_::bottom_));
}
HeaderBBox::~HeaderBBox() {
  // @@protoc_insertion_point(destructor:OSMPBF.HeaderBBox)
  SharedDtor(*this);
}
inline void HeaderBBox::SharedDtor(MessageLite& self) {
  HeaderBBox& this_ = static_cast<HeaderBBox&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite HeaderBBox_class_data_ =
    HeaderBBox::InternalGenerateClassData_(HeaderBBox_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
HeaderBBox::GetClassData() const {
  return HeaderBBox_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
HeaderBBox::GetClassData() const {
  return HeaderBBox_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const HeaderBBox::ParseTableT_
    HeaderBBox::_table_ =
        HeaderBBox::InternalGenerateParseTable_(HeaderBBox_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void HeaderBBox::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.HeaderBBox)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    ::memset(&_impl_.left_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.bottom_) -
        reinterpret_cast<char*>(&_impl_.left_)) + sizeof(_impl_.bottom_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL HeaderBBox::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const HeaderBBox& this_ = static_cast<const HeaderBBox&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL HeaderBBox::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const HeaderBBox& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.HeaderBBox)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required sint64 left = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteSInt64ToArray(
        1, this_._internal_left(), target);
  }

  // required sint64 right = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteSInt64ToArray(
        2, this_._internal_right(), target);
  }

  // required sint64 top = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteSInt64ToArray(
        3, this_._internal_top(), target);
  }

  // required sint64 bottom = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteSInt64ToArray(
        4, this_._internal_bottom(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.HeaderBBox)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t HeaderBBox::ByteSizeLong(const MessageLite& base) {
  const HeaderBBox& this_ = static_cast<const HeaderBBox&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t HeaderBBox::ByteSizeLong() const {
  const HeaderBBox& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.HeaderBBox)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // required sint64 left = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += ::_pbi::WireFormatLite::SInt64SizePlusOne(
          this_._internal_left());
    }
    // required sint64 right = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += ::_pbi::WireFormatLite::SInt64SizePlusOne(
          this_._internal_right());
    }
    // required sint64 top = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += ::_pbi::WireFormatLite::SInt64SizePlusOne(
          this_._internal_top());
    }
    // required sint64 bottom = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += ::_pbi::WireFormatLite::SInt64SizePlusOne(
          this_._internal_bottom());
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void HeaderBBox::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<HeaderBBox*>(&to_msg);
  auto& from = static_cast<const HeaderBBox&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.HeaderBBox)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_impl_.left_ = from._impl_.left_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_impl_.right_ = from._impl_.right_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.top_ = from._impl_.top_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_impl_.bottom_ = from._impl_.bottom_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void HeaderBBox::CopyFrom(const HeaderBBox& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.HeaderBBox)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool HeaderBBox::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const HeaderBBox&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void HeaderBBox::InternalSwap(HeaderBBox* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.bottom_)
      + sizeof(HeaderBBox::_impl_.bottom_)
      - PROTOBUF_FIELD_OFFSET(HeaderBBox, _impl_.left_)>(
          reinterpret_cast<char*>(&_impl_.left_),
          reinterpret_cast<char*>(&other->_impl_.left_));
}

// ===================================================================

PrimitiveBlock::PrimitiveBlock(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, PrimitiveBlock_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.PrimitiveBlock)
}
PROTOBUF_NDEBUG_INLINE PrimitiveBlock::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::PrimitiveBlock& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        primitivegroup_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::PrimitiveBlock,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveBlock, _impl_.primitivegroup_)>()
          , from.primitivegroup_
        }
     {}

PrimitiveBlock::PrimitiveBlock(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const PrimitiveBlock& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, PrimitiveBlock_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  PrimitiveBlock* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.stringtable_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.stringtable_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, lat_offset_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, lat_offset_),
           offsetof(Impl_, date_granularity_) -
               offsetof(Impl_, lat_offset_) +
               sizeof(Impl_::date_granularity_));

  // @@protoc_insertion_point(copy_constructor:OSMPBF.PrimitiveBlock)
}
PROTOBUF_NDEBUG_INLINE PrimitiveBlock::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        primitivegroup_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveBlock,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveBlock, _impl_.primitivegroup_)>()
         }
        ,
        granularity_{100},
        date_granularity_{1000} {}

inline void PrimitiveBlock::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, stringtable_),
           0,
           offsetof(Impl_, lon_offset_) -
               offsetof(Impl_, stringtable_) +
               sizeof(Impl_::lon_offset_));
}
PrimitiveBlock::~PrimitiveBlock() {
  // @@protoc_insertion_point(destructor:OSMPBF.PrimitiveBlock)
  SharedDtor(*this);
}
inline void PrimitiveBlock::SharedDtor(MessageLite& self) {
  PrimitiveBlock& this_ = static_cast<PrimitiveBlock&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.stringtable_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite PrimitiveBlock_class_data_ =
    PrimitiveBlock::InternalGenerateClassData_(PrimitiveBlock_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
PrimitiveBlock::GetClassData() const {
  return PrimitiveBlock_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
PrimitiveBlock::GetClassData() const {
  return PrimitiveBlock_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const PrimitiveBlock::ParseTableT_
    PrimitiveBlock::_table_ =
        PrimitiveBlock::InternalGenerateParseTable_(PrimitiveBlock_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void PrimitiveBlock::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.PrimitiveBlock)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.primitivegroup_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.stringtable_ != nullptr);
      _impl_.stringtable_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000003cU)) {
    ::memset(&_impl_.lat_offset_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.lon_offset_) -
        reinterpret_cast<char*>(&_impl_.lat_offset_)) + sizeof(_impl_.lon_offset_));
    _impl_.granularity_ = 100;
    _impl_.date_granularity_ = 1000;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL PrimitiveBlock::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const PrimitiveBlock& this_ = static_cast<const PrimitiveBlock&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL PrimitiveBlock::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const PrimitiveBlock& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.PrimitiveBlock)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required .OSMPBF.StringTable stringtable = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.stringtable_, this_._impl_.stringtable_->GetCachedSize(), target,
        stream);
  }

  // repeated .OSMPBF.PrimitiveGroup primitivegroup = 2;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_primitivegroup_size());
         i < n; i++) {
      const auto& repfield = this_._internal_primitivegroup().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              2, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // optional int32 granularity = 17 [default = 100];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteInt32ToArray(
        17, this_._internal_granularity(), target);
  }

  // optional int32 date_granularity = 18 [default = 1000];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteInt32ToArray(
        18, this_._internal_date_granularity(), target);
  }

  // optional int64 lat_offset = 19 [default = 0];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteInt64ToArray(
        19, this_._internal_lat_offset(), target);
  }

  // optional int64 lon_offset = 20 [default = 0];
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteInt64ToArray(
        20, this_._internal_lon_offset(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.PrimitiveBlock)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t PrimitiveBlock::ByteSizeLong(const MessageLite& base) {
  const PrimitiveBlock& this_ = static_cast<const PrimitiveBlock&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t PrimitiveBlock::ByteSizeLong() const {
  const PrimitiveBlock& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.PrimitiveBlock)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .OSMPBF.PrimitiveGroup primitivegroup = 2;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_primitivegroup_size();
      for (const auto& msg : this_._internal_primitivegroup()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
   {
    // required .OSMPBF.StringTable stringtable = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.stringtable_);
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000003cU)) {
    // optional int64 lat_offset = 19 [default = 0];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 2 + ::_pbi::WireFormatLite::Int64Size(
                                      this_._internal_lat_offset());
    }
    // optional int64 lon_offset = 20 [default = 0];
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 2 + ::_pbi::WireFormatLite::Int64Size(
                                      this_._internal_lon_offset());
    }
    // optional int32 granularity = 17 [default = 100];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 2 + ::_pbi::WireFormatLite::Int32Size(
                                      this_._internal_granularity());
    }
    // optional int32 date_granularity = 18 [default = 1000];
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += 2 + ::_pbi::WireFormatLite::Int32Size(
                                      this_._internal_date_granularity());
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void PrimitiveBlock::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<PrimitiveBlock*>(&to_msg);
  auto& from = static_cast<const PrimitiveBlock&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.PrimitiveBlock)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_primitivegroup()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_primitivegroup());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.stringtable_ != nullptr);
      if (_this->_impl_.stringtable_ == nullptr) {
        _this->_impl_.stringtable_ = ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.stringtable_);
      } else {
        _this->_impl_.stringtable_->MergeFrom(*from._impl_.stringtable_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.lat_offset_ = from._impl_.lat_offset_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_impl_.lon_offset_ = from._impl_.lon_offset_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_impl_.granularity_ = from._impl_.granularity_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_impl_.date_granularity_ = from._impl_.date_granularity_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void PrimitiveBlock::CopyFrom(const PrimitiveBlock& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.PrimitiveBlock)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool PrimitiveBlock::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const PrimitiveBlock&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  if (!::google::protobuf::internal::AllAreInitialized(this_._internal_primitivegroup()))
    return false;
  return true;
}

void PrimitiveBlock::InternalSwap(PrimitiveBlock* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.primitivegroup_.InternalSwap(&other->_impl_.primitivegroup_);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.date_granularity_)
      + sizeof(PrimitiveBlock::_impl_.date_granularity_)
      - PROTOBUF_FIELD_OFFSET(PrimitiveBlock, _impl_.stringtable_)>(
          reinterpret_cast<char*>(&_impl_.stringtable_),
          reinterpret_cast<char*>(&other->_impl_.stringtable_));
}

// ===================================================================

PrimitiveGroup::PrimitiveGroup(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, PrimitiveGroup_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.PrimitiveGroup)
}
PROTOBUF_NDEBUG_INLINE PrimitiveGroup::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::PrimitiveGroup& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        nodes_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::PrimitiveGroup,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.nodes_)>()
          , from.nodes_
        }
        ,
        ways_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::PrimitiveGroup,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.ways_)>()
          , from.ways_
        }
        ,
        relations_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::PrimitiveGroup,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.relations_)>()
          , from.relations_
        }
        ,
        changesets_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::PrimitiveGroup,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.changesets_)>()
          , from.changesets_
        }
     {}

PrimitiveGroup::PrimitiveGroup(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const PrimitiveGroup& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, PrimitiveGroup_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  PrimitiveGroup* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.dense_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.dense_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:OSMPBF.PrimitiveGroup)
}
PROTOBUF_NDEBUG_INLINE PrimitiveGroup::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        nodes_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.nodes_)>()
         }
        ,
        ways_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.ways_)>()
         }
        ,
        relations_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.relations_)>()
         }
        ,
        changesets_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::PrimitiveGroup,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::PrimitiveGroup, _impl_.changesets_)>()
         }
     {}

inline void PrimitiveGroup::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.dense_ = {};
}
PrimitiveGroup::~PrimitiveGroup() {
  // @@protoc_insertion_point(destructor:OSMPBF.PrimitiveGroup)
  SharedDtor(*this);
}
inline void PrimitiveGroup::SharedDtor(MessageLite& self) {
  PrimitiveGroup& this_ = static_cast<PrimitiveGroup&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.dense_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite PrimitiveGroup_class_data_ =
    PrimitiveGroup::InternalGenerateClassData_(PrimitiveGroup_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
PrimitiveGroup::GetClassData() const {
  return PrimitiveGroup_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
PrimitiveGroup::GetClassData() const {
  return PrimitiveGroup_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const PrimitiveGroup::ParseTableT_
    PrimitiveGroup::_table_ =
        PrimitiveGroup::InternalGenerateParseTable_(PrimitiveGroup_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void PrimitiveGroup::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.PrimitiveGroup)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.nodes_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.ways_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.relations_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.changesets_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.dense_ != nullptr);
      _impl_.dense_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL PrimitiveGroup::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const PrimitiveGroup& this_ = static_cast<const PrimitiveGroup&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL PrimitiveGroup::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const PrimitiveGroup& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.PrimitiveGroup)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .OSMPBF.Node nodes = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_nodes_size());
         i < n; i++) {
      const auto& repfield = this_._internal_nodes().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // optional .OSMPBF.DenseNodes dense = 2;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.dense_, this_._impl_.dense_->GetCachedSize(), target,
        stream);
  }

  // repeated .OSMPBF.Way ways = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_ways_size());
         i < n; i++) {
      const auto& repfield = this_._internal_ways().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              3, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // repeated .OSMPBF.Relation relations = 4;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_relations_size());
         i < n; i++) {
      const auto& repfield = this_._internal_relations().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              4, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // repeated .OSMPBF.ChangeSet changesets = 5;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_changesets_size());
         i < n; i++) {
      const auto& repfield = this_._internal_changesets().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              5, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.PrimitiveGroup)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t PrimitiveGroup::ByteSizeLong(const MessageLite& base) {
  const PrimitiveGroup& this_ = static_cast<const PrimitiveGroup&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t PrimitiveGroup::ByteSizeLong() const {
  const PrimitiveGroup& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.PrimitiveGroup)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // repeated .OSMPBF.Node nodes = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_nodes_size();
      for (const auto& msg : this_._internal_nodes()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .OSMPBF.Way ways = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1UL * this_._internal_ways_size();
      for (const auto& msg : this_._internal_ways()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .OSMPBF.Relation relations = 4;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1UL * this_._internal_relations_size();
      for (const auto& msg : this_._internal_relations()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .OSMPBF.ChangeSet changesets = 5;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1UL * this_._internal_changesets_size();
      for (const auto& msg : this_._internal_changesets()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // optional .OSMPBF.DenseNodes dense = 2;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.dense_);
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void PrimitiveGroup::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<PrimitiveGroup*>(&to_msg);
  auto& from = static_cast<const PrimitiveGroup&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.PrimitiveGroup)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_nodes()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_nodes());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_ways()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_ways());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_mutable_relations()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_relations());
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_internal_mutable_changesets()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_changesets());
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.dense_ != nullptr);
      if (_this->_impl_.dense_ == nullptr) {
        _this->_impl_.dense_ = ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.dense_);
      } else {
        _this->_impl_.dense_->MergeFrom(*from._impl_.dense_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void PrimitiveGroup::CopyFrom(const PrimitiveGroup& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.PrimitiveGroup)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool PrimitiveGroup::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const PrimitiveGroup&>(msg);
  if (!::google::protobuf::internal::AllAreInitialized(this_._internal_nodes()))
    return false;
  if (!::google::protobuf::internal::AllAreInitialized(this_._internal_ways()))
    return false;
  if (!::google::protobuf::internal::AllAreInitialized(this_._internal_relations()))
    return false;
  if (!::google::protobuf::internal::AllAreInitialized(this_._internal_changesets()))
    return false;
  return true;
}

void PrimitiveGroup::InternalSwap(PrimitiveGroup* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.nodes_.InternalSwap(&other->_impl_.nodes_);
  _impl_.ways_.InternalSwap(&other->_impl_.ways_);
  _impl_.relations_.InternalSwap(&other->_impl_.relations_);
  _impl_.changesets_.InternalSwap(&other->_impl_.changesets_);
  swap(_impl_.dense_, other->_impl_.dense_);
}

// ===================================================================

StringTable::StringTable(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, StringTable_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.StringTable)
}
PROTOBUF_NDEBUG_INLINE StringTable::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::StringTable& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        s_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::StringTable,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::StringTable, _impl_.s_)>()
          , from.s_
        }
     {}

StringTable::StringTable(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const StringTable& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, StringTable_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  StringTable* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:OSMPBF.StringTable)
}
PROTOBUF_NDEBUG_INLINE StringTable::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        s_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::StringTable,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::StringTable, _impl_.s_)>()
         }
     {}

inline void StringTable::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
StringTable::~StringTable() {
  // @@protoc_insertion_point(destructor:OSMPBF.StringTable)
  SharedDtor(*this);
}
inline void StringTable::SharedDtor(MessageLite& self) {
  StringTable& this_ = static_cast<StringTable&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite StringTable_class_data_ =
    StringTable::InternalGenerateClassData_(StringTable_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
StringTable::GetClassData() const {
  return StringTable_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
StringTable::GetClassData() const {
  return StringTable_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const StringTable::ParseTableT_
    StringTable::_table_ =
        StringTable::InternalGenerateParseTable_(StringTable_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void StringTable::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.StringTable)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.s_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL StringTable::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const StringTable& this_ = static_cast<const StringTable&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL StringTable::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const StringTable& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.StringTable)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated bytes s = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (int i = 0, n = this_._internal_s_size(); i < n; ++i) {
      const auto& s = this_._internal_s().Get(i);
      target = stream->WriteBytes(1, s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.StringTable)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t StringTable::ByteSizeLong(const MessageLite& base) {
  const StringTable& this_ = static_cast<const StringTable&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t StringTable::ByteSizeLong() const {
  const StringTable& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.StringTable)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated bytes s = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_s().size());
      for (int i = 0, n = this_._internal_s().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::BytesSize(
            this_._internal_s().Get(i));
      }
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void StringTable::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<StringTable*>(&to_msg);
  auto& from = static_cast<const StringTable&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.StringTable)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_s()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_s());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void StringTable::CopyFrom(const StringTable& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.StringTable)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void StringTable::InternalSwap(StringTable* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.s_.InternalSwap(&other->_impl_.s_);
}

// ===================================================================

Info::Info(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Info_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.Info)
}
Info::Info(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Info& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Info_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE Info::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        version_{-1} {}

inline void Info::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, timestamp_),
           0,
           offsetof(Impl_, visible_) -
               offsetof(Impl_, timestamp_) +
               sizeof(Impl_::visible_));
}
Info::~Info() {
  // @@protoc_insertion_point(destructor:OSMPBF.Info)
  SharedDtor(*this);
}
inline void Info::SharedDtor(MessageLite& self) {
  Info& this_ = static_cast<Info&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite Info_class_data_ =
    Info::InternalGenerateClassData_(Info_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Info::GetClassData() const {
  return Info_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Info::GetClassData() const {
  return Info_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Info::ParseTableT_
    Info::_table_ =
        Info::InternalGenerateParseTable_(Info_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Info::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.Info)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    ::memset(&_impl_.timestamp_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.visible_) -
        reinterpret_cast<char*>(&_impl_.timestamp_)) + sizeof(_impl_.visible_));
    _impl_.version_ = -1;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Info::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Info& this_ = static_cast<const Info&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Info::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Info& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.Info)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // optional int32 version = 1 [default = -1];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target =
        ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<1>(
            stream, this_._internal_version(), target);
  }

  // optional int64 timestamp = 2;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target =
        ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<2>(
            stream, this_._internal_timestamp(), target);
  }

  // optional int64 changeset = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target =
        ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<3>(
            stream, this_._internal_changeset(), target);
  }

  // optional int32 uid = 4;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target =
        ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
            stream, this_._internal_uid(), target);
  }

  // optional uint32 user_sid = 5;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
        5, this_._internal_user_sid(), target);
  }

  // optional bool visible = 6;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        6, this_._internal_visible(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.Info)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Info::ByteSizeLong(const MessageLite& base) {
  const Info& this_ = static_cast<const Info&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Info::ByteSizeLong() const {
  const Info& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.Info)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += static_cast<bool>(0x00000010U & cached_has_bits) * 2;
  if (BatchCheckHasBit(cached_has_bits, 0x0000002fU)) {
    // optional int64 timestamp = 2;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
          this_._internal_timestamp());
    }
    // optional int64 changeset = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
          this_._internal_changeset());
    }
    // optional int32 uid = 4;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
          this_._internal_uid());
    }
    // optional uint32 user_sid = 5;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
          this_._internal_user_sid());
    }
    // optional int32 version = 1 [default = -1];
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
          this_._internal_version());
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void Info::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Info*>(&to_msg);
  auto& from = static_cast<const Info&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.Info)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_impl_.timestamp_ = from._impl_.timestamp_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_impl_.changeset_ = from._impl_.changeset_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.uid_ = from._impl_.uid_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_impl_.user_sid_ = from._impl_.user_sid_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_impl_.visible_ = from._impl_.visible_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_impl_.version_ = from._impl_.version_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void Info::CopyFrom(const Info& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.Info)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Info::InternalSwap(Info* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Info, _impl_.version_)
      + sizeof(Info::_impl_.version_)
      - PROTOBUF_FIELD_OFFSET(Info, _impl_.timestamp_)>(
          reinterpret_cast<char*>(&_impl_.timestamp_),
          reinterpret_cast<char*>(&other->_impl_.timestamp_));
}

// ===================================================================

DenseInfo::DenseInfo(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, DenseInfo_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.DenseInfo)
}
PROTOBUF_NDEBUG_INLINE DenseInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::DenseInfo& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        version_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseInfo,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.version_)>()
          , from.version_
        }
        ,
        _version_cached_byte_size_{0},
        timestamp_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseInfo,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.timestamp_)>()
          , from.timestamp_
        }
        ,
        _timestamp_cached_byte_size_{0},
        changeset_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseInfo,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.changeset_)>()
          , from.changeset_
        }
        ,
        _changeset_cached_byte_size_{0},
        uid_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseInfo,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.uid_)>()
          , from.uid_
        }
        ,
        _uid_cached_byte_size_{0},
        user_sid_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseInfo,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.user_sid_)>()
          , from.user_sid_
        }
        ,
        _user_sid_cached_byte_size_{0},
        visible_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseInfo,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.visible_)>()
          , from.visible_
        }
     {}

DenseInfo::DenseInfo(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const DenseInfo& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, DenseInfo_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  DenseInfo* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:OSMPBF.DenseInfo)
}
PROTOBUF_NDEBUG_INLINE DenseInfo::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        version_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.version_)>()
         }
        ,
        _version_cached_byte_size_{0},
        timestamp_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.timestamp_)>()
         }
        ,
        _timestamp_cached_byte_size_{0},
        changeset_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.changeset_)>()
         }
        ,
        _changeset_cached_byte_size_{0},
        uid_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.uid_)>()
         }
        ,
        _uid_cached_byte_size_{0},
        user_sid_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.user_sid_)>()
         }
        ,
        _user_sid_cached_byte_size_{0},
        visible_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseInfo,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseInfo, _impl_.visible_)>()
         }
     {}

inline void DenseInfo::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
DenseInfo::~DenseInfo() {
  // @@protoc_insertion_point(destructor:OSMPBF.DenseInfo)
  SharedDtor(*this);
}
inline void DenseInfo::SharedDtor(MessageLite& self) {
  DenseInfo& this_ = static_cast<DenseInfo&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite DenseInfo_class_data_ =
    DenseInfo::InternalGenerateClassData_(DenseInfo_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DenseInfo::GetClassData() const {
  return DenseInfo_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DenseInfo::GetClassData() const {
  return DenseInfo_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const DenseInfo::ParseTableT_
    DenseInfo::_table_ =
        DenseInfo::InternalGenerateParseTable_(DenseInfo_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void DenseInfo::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.DenseInfo)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.version_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.timestamp_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.changeset_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.uid_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.user_sid_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _impl_.visible_.Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL DenseInfo::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const DenseInfo& this_ = static_cast<const DenseInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL DenseInfo::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const DenseInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.DenseInfo)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated int32 version = 1 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    {
      int byte_size = this_._impl_._version_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteInt32Packed(
            1, this_._internal_version(), byte_size, target);
      }
    }
  }

  // repeated sint64 timestamp = 2 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    {
      int byte_size = this_._impl_._timestamp_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt64Packed(
            2, this_._internal_timestamp(), byte_size, target);
      }
    }
  }

  // repeated sint64 changeset = 3 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    {
      int byte_size = this_._impl_._changeset_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt64Packed(
            3, this_._internal_changeset(), byte_size, target);
      }
    }
  }

  // repeated sint32 uid = 4 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    {
      int byte_size = this_._impl_._uid_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt32Packed(
            4, this_._internal_uid(), byte_size, target);
      }
    }
  }

  // repeated sint32 user_sid = 5 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    {
      int byte_size = this_._impl_._user_sid_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt32Packed(
            5, this_._internal_user_sid(), byte_size, target);
      }
    }
  }

  // repeated bool visible = 6 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_visible_size() > 0) {
      target = stream->WriteFixedPacked(6, this_._internal_visible(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.DenseInfo)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t DenseInfo::ByteSizeLong(const MessageLite& base) {
  const DenseInfo& this_ = static_cast<const DenseInfo&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t DenseInfo::ByteSizeLong() const {
  const DenseInfo& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.DenseInfo)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // repeated int32 version = 1 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          ::_pbi::WireFormatLite::Int32SizeWithPackedTagSize(
              this_._internal_version(), 1,
              this_._impl_._version_cached_byte_size_);
    }
    // repeated sint64 timestamp = 2 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt64SizeWithPackedTagSize(
              this_._internal_timestamp(), 1,
              this_._impl_._timestamp_cached_byte_size_);
    }
    // repeated sint64 changeset = 3 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt64SizeWithPackedTagSize(
              this_._internal_changeset(), 1,
              this_._impl_._changeset_cached_byte_size_);
    }
    // repeated sint32 uid = 4 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt32SizeWithPackedTagSize(
              this_._internal_uid(), 1,
              this_._impl_._uid_cached_byte_size_);
    }
    // repeated sint32 user_sid = 5 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt32SizeWithPackedTagSize(
              this_._internal_user_sid(), 1,
              this_._impl_._user_sid_cached_byte_size_);
    }
    // repeated bool visible = 6 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ::size_t data_size = ::size_t{1} *
          ::_pbi::FromIntSize(this_._internal_visible_size());
      ::size_t tag_size = data_size == 0
          ? 0
          : 1 + ::_pbi::WireFormatLite::Int32Size(
                              static_cast<::int32_t>(data_size));
      total_size += tag_size + data_size;
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void DenseInfo::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<DenseInfo*>(&to_msg);
  auto& from = static_cast<const DenseInfo&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.DenseInfo)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_version()->MergeFrom(from._internal_version());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_timestamp()->MergeFrom(from._internal_timestamp());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_mutable_changeset()->MergeFrom(from._internal_changeset());
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_internal_mutable_uid()->MergeFrom(from._internal_uid());
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_internal_mutable_user_sid()->MergeFrom(from._internal_user_sid());
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_internal_mutable_visible()->MergeFrom(from._internal_visible());
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void DenseInfo::CopyFrom(const DenseInfo& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.DenseInfo)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void DenseInfo::InternalSwap(DenseInfo* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.version_.InternalSwap(&other->_impl_.version_);
  _impl_.timestamp_.InternalSwap(&other->_impl_.timestamp_);
  _impl_.changeset_.InternalSwap(&other->_impl_.changeset_);
  _impl_.uid_.InternalSwap(&other->_impl_.uid_);
  _impl_.user_sid_.InternalSwap(&other->_impl_.user_sid_);
  _impl_.visible_.InternalSwap(&other->_impl_.visible_);
}

// ===================================================================

ChangeSet::ChangeSet(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, ChangeSet_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.ChangeSet)
}
ChangeSet::ChangeSet(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ChangeSet& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, ChangeSet_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE ChangeSet::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ChangeSet::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.id_ = {};
}
ChangeSet::~ChangeSet() {
  // @@protoc_insertion_point(destructor:OSMPBF.ChangeSet)
  SharedDtor(*this);
}
inline void ChangeSet::SharedDtor(MessageLite& self) {
  ChangeSet& this_ = static_cast<ChangeSet&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite ChangeSet_class_data_ =
    ChangeSet::InternalGenerateClassData_(ChangeSet_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ChangeSet::GetClassData() const {
  return ChangeSet_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ChangeSet::GetClassData() const {
  return ChangeSet_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ChangeSet::ParseTableT_
    ChangeSet::_table_ =
        ChangeSet::InternalGenerateParseTable_(ChangeSet_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ChangeSet::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.ChangeSet)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.id_ = ::int64_t{0};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ChangeSet::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ChangeSet& this_ = static_cast<const ChangeSet&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ChangeSet::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ChangeSet& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.ChangeSet)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required int64 id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target =
        ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<1>(
            stream, this_._internal_id(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.ChangeSet)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ChangeSet::ByteSizeLong(const MessageLite& base) {
  const ChangeSet& this_ = static_cast<const ChangeSet&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ChangeSet::ByteSizeLong() const {
  const ChangeSet& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.ChangeSet)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // required int64 id = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
          this_._internal_id());
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void ChangeSet::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ChangeSet*>(&to_msg);
  auto& from = static_cast<const ChangeSet&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.ChangeSet)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_impl_.id_ = from._impl_.id_;
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void ChangeSet::CopyFrom(const ChangeSet& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.ChangeSet)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool ChangeSet::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const ChangeSet&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void ChangeSet::InternalSwap(ChangeSet* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.id_, other->_impl_.id_);
}

// ===================================================================

Node::Node(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Node_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.Node)
}
PROTOBUF_NDEBUG_INLINE Node::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::Node& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        keys_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Node,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Node, _impl_.keys_)>()
          , from.keys_
        }
        ,
        _keys_cached_byte_size_{0},
        vals_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Node,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Node, _impl_.vals_)>()
          , from.vals_
        }
        ,
        _vals_cached_byte_size_{0} {}

Node::Node(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Node& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Node_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Node* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.info_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.info_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, id_),
           offsetof(Impl_, lon_) -
               offsetof(Impl_, id_) +
               sizeof(Impl_::lon_));

  // @@protoc_insertion_point(copy_constructor:OSMPBF.Node)
}
PROTOBUF_NDEBUG_INLINE Node::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        keys_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Node,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Node, _impl_.keys_)>()
         }
        ,
        _keys_cached_byte_size_{0},
        vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Node,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Node, _impl_.vals_)>()
         }
        ,
        _vals_cached_byte_size_{0} {}

inline void Node::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, info_),
           0,
           offsetof(Impl_, lon_) -
               offsetof(Impl_, info_) +
               sizeof(Impl_::lon_));
}
Node::~Node() {
  // @@protoc_insertion_point(destructor:OSMPBF.Node)
  SharedDtor(*this);
}
inline void Node::SharedDtor(MessageLite& self) {
  Node& this_ = static_cast<Node&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.info_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite Node_class_data_ =
    Node::InternalGenerateClassData_(Node_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Node::GetClassData() const {
  return Node_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Node::GetClassData() const {
  return Node_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Node::ParseTableT_
    Node::_table_ =
        Node::InternalGenerateParseTable_(Node_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Node::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.Node)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.keys_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.vals_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.info_ != nullptr);
      _impl_.info_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000038U)) {
    ::memset(&_impl_.id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.lon_) -
        reinterpret_cast<char*>(&_impl_.id_)) + sizeof(_impl_.lon_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Node::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Node& this_ = static_cast<const Node&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Node::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Node& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.Node)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required sint64 id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteSInt64ToArray(
        1, this_._internal_id(), target);
  }

  // repeated uint32 keys = 2 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    {
      int byte_size = this_._impl_._keys_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteUInt32Packed(
            2, this_._internal_keys(), byte_size, target);
      }
    }
  }

  // repeated uint32 vals = 3 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    {
      int byte_size = this_._impl_._vals_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteUInt32Packed(
            3, this_._internal_vals(), byte_size, target);
      }
    }
  }

  // optional .OSMPBF.Info info = 4;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        4, *this_._impl_.info_, this_._impl_.info_->GetCachedSize(), target,
        stream);
  }

  // required sint64 lat = 8;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteSInt64ToArray(
        8, this_._internal_lat(), target);
  }

  // required sint64 lon = 9;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteSInt64ToArray(
        9, this_._internal_lon(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.Node)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Node::ByteSizeLong(const MessageLite& base) {
  const Node& this_ = static_cast<const Node&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Node::ByteSizeLong() const {
  const Node& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.Node)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // repeated uint32 keys = 2 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          ::_pbi::WireFormatLite::UInt32SizeWithPackedTagSize(
              this_._internal_keys(), 1,
              this_._impl_._keys_cached_byte_size_);
    }
    // repeated uint32 vals = 3 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size +=
          ::_pbi::WireFormatLite::UInt32SizeWithPackedTagSize(
              this_._internal_vals(), 1,
              this_._impl_._vals_cached_byte_size_);
    }
    // optional .OSMPBF.Info info = 4;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.info_);
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000038U)) {
    // required sint64 id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += ::_pbi::WireFormatLite::SInt64SizePlusOne(
          this_._internal_id());
    }
    // required sint64 lat = 8;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += ::_pbi::WireFormatLite::SInt64SizePlusOne(
          this_._internal_lat());
    }
    // required sint64 lon = 9;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += ::_pbi::WireFormatLite::SInt64SizePlusOne(
          this_._internal_lon());
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void Node::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Node*>(&to_msg);
  auto& from = static_cast<const Node&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.Node)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_keys()->MergeFrom(from._internal_keys());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_vals()->MergeFrom(from._internal_vals());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.info_ != nullptr);
      if (_this->_impl_.info_ == nullptr) {
        _this->_impl_.info_ = ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.info_);
      } else {
        _this->_impl_.info_->MergeFrom(*from._impl_.info_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_impl_.id_ = from._impl_.id_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_impl_.lat_ = from._impl_.lat_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_impl_.lon_ = from._impl_.lon_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void Node::CopyFrom(const Node& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.Node)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool Node::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const Node&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void Node::InternalSwap(Node* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.keys_.InternalSwap(&other->_impl_.keys_);
  _impl_.vals_.InternalSwap(&other->_impl_.vals_);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Node, _impl_.lon_)
      + sizeof(Node::_impl_.lon_)
      - PROTOBUF_FIELD_OFFSET(Node, _impl_.info_)>(
          reinterpret_cast<char*>(&_impl_.info_),
          reinterpret_cast<char*>(&other->_impl_.info_));
}

// ===================================================================

DenseNodes::DenseNodes(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, DenseNodes_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.DenseNodes)
}
PROTOBUF_NDEBUG_INLINE DenseNodes::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::DenseNodes& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        id_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseNodes,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.id_)>()
          , from.id_
        }
        ,
        _id_cached_byte_size_{0},
        lat_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseNodes,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.lat_)>()
          , from.lat_
        }
        ,
        _lat_cached_byte_size_{0},
        keys_vals_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseNodes,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.keys_vals_)>()
          , from.keys_vals_
        }
        ,
        _keys_vals_cached_byte_size_{0},
        lon_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::DenseNodes,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.lon_)>()
          , from.lon_
        }
        ,
        _lon_cached_byte_size_{0} {}

DenseNodes::DenseNodes(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const DenseNodes& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, DenseNodes_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  DenseNodes* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.denseinfo_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.denseinfo_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:OSMPBF.DenseNodes)
}
PROTOBUF_NDEBUG_INLINE DenseNodes::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        id_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.id_)>()
         }
        ,
        _id_cached_byte_size_{0},
        lat_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.lat_)>()
         }
        ,
        _lat_cached_byte_size_{0},
        keys_vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.keys_vals_)>()
         }
        ,
        _keys_vals_cached_byte_size_{0},
        lon_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::DenseNodes,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::DenseNodes, _impl_.lon_)>()
         }
        ,
        _lon_cached_byte_size_{0} {}

inline void DenseNodes::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.denseinfo_ = {};
}
DenseNodes::~DenseNodes() {
  // @@protoc_insertion_point(destructor:OSMPBF.DenseNodes)
  SharedDtor(*this);
}
inline void DenseNodes::SharedDtor(MessageLite& self) {
  DenseNodes& this_ = static_cast<DenseNodes&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.denseinfo_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite DenseNodes_class_data_ =
    DenseNodes::InternalGenerateClassData_(DenseNodes_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DenseNodes::GetClassData() const {
  return DenseNodes_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
DenseNodes::GetClassData() const {
  return DenseNodes_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const DenseNodes::ParseTableT_
    DenseNodes::_table_ =
        DenseNodes::InternalGenerateParseTable_(DenseNodes_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void DenseNodes::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.DenseNodes)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.id_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.lat_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.keys_vals_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.denseinfo_ != nullptr);
      _impl_.denseinfo_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.lon_.Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL DenseNodes::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const DenseNodes& this_ = static_cast<const DenseNodes&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL DenseNodes::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const DenseNodes& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.DenseNodes)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated sint64 id = 1 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    {
      int byte_size = this_._impl_._id_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt64Packed(
            1, this_._internal_id(), byte_size, target);
      }
    }
  }

  // optional .OSMPBF.DenseInfo denseinfo = 5;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        5, *this_._impl_.denseinfo_, this_._impl_.denseinfo_->GetCachedSize(), target,
        stream);
  }

  // repeated sint64 lat = 8 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    {
      int byte_size = this_._impl_._lat_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt64Packed(
            8, this_._internal_lat(), byte_size, target);
      }
    }
  }

  // repeated sint64 lon = 9 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    {
      int byte_size = this_._impl_._lon_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt64Packed(
            9, this_._internal_lon(), byte_size, target);
      }
    }
  }

  // repeated int32 keys_vals = 10 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    {
      int byte_size = this_._impl_._keys_vals_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteInt32Packed(
            10, this_._internal_keys_vals(), byte_size, target);
      }
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.DenseNodes)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t DenseNodes::ByteSizeLong(const MessageLite& base) {
  const DenseNodes& this_ = static_cast<const DenseNodes&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t DenseNodes::ByteSizeLong() const {
  const DenseNodes& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.DenseNodes)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // repeated sint64 id = 1 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt64SizeWithPackedTagSize(
              this_._internal_id(), 1,
              this_._impl_._id_cached_byte_size_);
    }
    // repeated sint64 lat = 8 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt64SizeWithPackedTagSize(
              this_._internal_lat(), 1,
              this_._impl_._lat_cached_byte_size_);
    }
    // repeated int32 keys_vals = 10 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size +=
          ::_pbi::WireFormatLite::Int32SizeWithPackedTagSize(
              this_._internal_keys_vals(), 1,
              this_._impl_._keys_vals_cached_byte_size_);
    }
    // optional .OSMPBF.DenseInfo denseinfo = 5;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.denseinfo_);
    }
    // repeated sint64 lon = 9 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt64SizeWithPackedTagSize(
              this_._internal_lon(), 1,
              this_._impl_._lon_cached_byte_size_);
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void DenseNodes::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<DenseNodes*>(&to_msg);
  auto& from = static_cast<const DenseNodes&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.DenseNodes)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_id()->MergeFrom(from._internal_id());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_lat()->MergeFrom(from._internal_lat());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_mutable_keys_vals()->MergeFrom(from._internal_keys_vals());
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.denseinfo_ != nullptr);
      if (_this->_impl_.denseinfo_ == nullptr) {
        _this->_impl_.denseinfo_ = ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.denseinfo_);
      } else {
        _this->_impl_.denseinfo_->MergeFrom(*from._impl_.denseinfo_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_internal_mutable_lon()->MergeFrom(from._internal_lon());
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void DenseNodes::CopyFrom(const DenseNodes& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.DenseNodes)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void DenseNodes::InternalSwap(DenseNodes* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.id_.InternalSwap(&other->_impl_.id_);
  _impl_.lat_.InternalSwap(&other->_impl_.lat_);
  _impl_.keys_vals_.InternalSwap(&other->_impl_.keys_vals_);
  swap(_impl_.denseinfo_, other->_impl_.denseinfo_);
  _impl_.lon_.InternalSwap(&other->_impl_.lon_);
}

// ===================================================================

Way::Way(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Way_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.Way)
}
PROTOBUF_NDEBUG_INLINE Way::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::Way& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        keys_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Way,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.keys_)>()
          , from.keys_
        }
        ,
        _keys_cached_byte_size_{0},
        vals_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Way,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.vals_)>()
          , from.vals_
        }
        ,
        _vals_cached_byte_size_{0},
        refs_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Way,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.refs_)>()
          , from.refs_
        }
        ,
        _refs_cached_byte_size_{0} {}

Way::Way(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Way& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Way_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Way* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.info_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.info_)
                : nullptr;
  _impl_.id_ = from._impl_.id_;

  // @@protoc_insertion_point(copy_constructor:OSMPBF.Way)
}
PROTOBUF_NDEBUG_INLINE Way::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        keys_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Way,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.keys_)>()
         }
        ,
        _keys_cached_byte_size_{0},
        vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Way,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.vals_)>()
         }
        ,
        _vals_cached_byte_size_{0},
        refs_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Way,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Way, _impl_.refs_)>()
         }
        ,
        _refs_cached_byte_size_{0} {}

inline void Way::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, info_),
           0,
           offsetof(Impl_, id_) -
               offsetof(Impl_, info_) +
               sizeof(Impl_::id_));
}
Way::~Way() {
  // @@protoc_insertion_point(destructor:OSMPBF.Way)
  SharedDtor(*this);
}
inline void Way::SharedDtor(MessageLite& self) {
  Way& this_ = static_cast<Way&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.info_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite Way_class_data_ =
    Way::InternalGenerateClassData_(Way_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Way::GetClassData() const {
  return Way_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Way::GetClassData() const {
  return Way_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Way::ParseTableT_
    Way::_table_ =
        Way::InternalGenerateParseTable_(Way_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Way::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.Way)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.keys_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.vals_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.refs_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.info_ != nullptr);
      _impl_.info_->Clear();
    }
  }
  _impl_.id_ = ::int64_t{0};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Way::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Way& this_ = static_cast<const Way&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Way::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Way& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.Way)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required int64 id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target =
        ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<1>(
            stream, this_._internal_id(), target);
  }

  // repeated uint32 keys = 2 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    {
      int byte_size = this_._impl_._keys_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteUInt32Packed(
            2, this_._internal_keys(), byte_size, target);
      }
    }
  }

  // repeated uint32 vals = 3 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    {
      int byte_size = this_._impl_._vals_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteUInt32Packed(
            3, this_._internal_vals(), byte_size, target);
      }
    }
  }

  // optional .OSMPBF.Info info = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        4, *this_._impl_.info_, this_._impl_.info_->GetCachedSize(), target,
        stream);
  }

  // repeated sint64 refs = 8 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    {
      int byte_size = this_._impl_._refs_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt64Packed(
            8, this_._internal_refs(), byte_size, target);
      }
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.Way)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Way::ByteSizeLong(const MessageLite& base) {
  const Way& this_ = static_cast<const Way&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Way::ByteSizeLong() const {
  const Way& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.Way)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // repeated uint32 keys = 2 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          ::_pbi::WireFormatLite::UInt32SizeWithPackedTagSize(
              this_._internal_keys(), 1,
              this_._impl_._keys_cached_byte_size_);
    }
    // repeated uint32 vals = 3 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size +=
          ::_pbi::WireFormatLite::UInt32SizeWithPackedTagSize(
              this_._internal_vals(), 1,
              this_._impl_._vals_cached_byte_size_);
    }
    // repeated sint64 refs = 8 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt64SizeWithPackedTagSize(
              this_._internal_refs(), 1,
              this_._impl_._refs_cached_byte_size_);
    }
    // optional .OSMPBF.Info info = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.info_);
    }
  }
   {
    // required int64 id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
          this_._internal_id());
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void Way::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Way*>(&to_msg);
  auto& from = static_cast<const Way&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.Way)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_keys()->MergeFrom(from._internal_keys());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_vals()->MergeFrom(from._internal_vals());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_mutable_refs()->MergeFrom(from._internal_refs());
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.info_ != nullptr);
      if (_this->_impl_.info_ == nullptr) {
        _this->_impl_.info_ = ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.info_);
      } else {
        _this->_impl_.info_->MergeFrom(*from._impl_.info_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_impl_.id_ = from._impl_.id_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void Way::CopyFrom(const Way& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.Way)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool Way::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const Way&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void Way::InternalSwap(Way* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.keys_.InternalSwap(&other->_impl_.keys_);
  _impl_.vals_.InternalSwap(&other->_impl_.vals_);
  _impl_.refs_.InternalSwap(&other->_impl_.refs_);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Way, _impl_.id_)
      + sizeof(Way::_impl_.id_)
      - PROTOBUF_FIELD_OFFSET(Way, _impl_.info_)>(
          reinterpret_cast<char*>(&_impl_.info_),
          reinterpret_cast<char*>(&other->_impl_.info_));
}

// ===================================================================

Relation::Relation(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Relation_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:OSMPBF.Relation)
}
PROTOBUF_NDEBUG_INLINE Relation::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::OSMPBF::Relation& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        keys_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Relation,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.keys_)>()
          , from.keys_
        }
        ,
        _keys_cached_byte_size_{0},
        vals_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Relation,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.vals_)>()
          , from.vals_
        }
        ,
        _vals_cached_byte_size_{0},
        roles_sid_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Relation,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.roles_sid_)>()
          , from.roles_sid_
        }
        ,
        _roles_sid_cached_byte_size_{0},
        memids_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Relation,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.memids_)>()
          , from.memids_
        }
        ,
        _memids_cached_byte_size_{0},
        types_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::OSMPBF::Relation,
              PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.types_)>()
          , from.types_
        }
        ,
        _types_cached_byte_size_{0} {}

Relation::Relation(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Relation& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::MessageLite(arena, Relation_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::MessageLite(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Relation* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.info_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.info_)
                : nullptr;
  _impl_.id_ = from._impl_.id_;

  // @@protoc_insertion_point(copy_constructor:OSMPBF.Relation)
}
PROTOBUF_NDEBUG_INLINE Relation::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        keys_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.keys_)>()
         }
        ,
        _keys_cached_byte_size_{0},
        vals_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.vals_)>()
         }
        ,
        _vals_cached_byte_size_{0},
        roles_sid_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.roles_sid_)>()
         }
        ,
        _roles_sid_cached_byte_size_{0},
        memids_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.memids_)>()
         }
        ,
        _memids_cached_byte_size_{0},
        types_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::OSMPBF::Relation,
            PROTOBUF_FIELD_OFFSET(::OSMPBF::Relation, _impl_.types_)>()
         }
        ,
        _types_cached_byte_size_{0} {}

inline void Relation::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, info_),
           0,
           offsetof(Impl_, id_) -
               offsetof(Impl_, info_) +
               sizeof(Impl_::id_));
}
Relation::~Relation() {
  // @@protoc_insertion_point(destructor:OSMPBF.Relation)
  SharedDtor(*this);
}
inline void Relation::SharedDtor(MessageLite& self) {
  Relation& this_ = static_cast<Relation&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::std::string>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.info_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::google::protobuf::internal::ClassDataLite Relation_class_data_ =
    Relation::InternalGenerateClassData_(Relation_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Relation::GetClassData() const {
  return Relation_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Relation::GetClassData() const {
  return Relation_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Relation::ParseTableT_
    Relation::_table_ =
        Relation::InternalGenerateParseTable_(Relation_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Relation::Clear() {
// @@protoc_insertion_point(message_clear_start:OSMPBF.Relation)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.keys_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.vals_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.roles_sid_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.info_ != nullptr);
      _impl_.info_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000070U)) {
    _impl_.id_ = ::int64_t{0};
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _impl_.memids_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _impl_.types_.Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::std::string>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Relation::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Relation& this_ = static_cast<const Relation&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Relation::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Relation& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:OSMPBF.Relation)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required int64 id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target =
        ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<1>(
            stream, this_._internal_id(), target);
  }

  // repeated uint32 keys = 2 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    {
      int byte_size = this_._impl_._keys_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteUInt32Packed(
            2, this_._internal_keys(), byte_size, target);
      }
    }
  }

  // repeated uint32 vals = 3 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    {
      int byte_size = this_._impl_._vals_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteUInt32Packed(
            3, this_._internal_vals(), byte_size, target);
      }
    }
  }

  // optional .OSMPBF.Info info = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        4, *this_._impl_.info_, this_._impl_.info_->GetCachedSize(), target,
        stream);
  }

  // repeated int32 roles_sid = 8 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    {
      int byte_size = this_._impl_._roles_sid_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteInt32Packed(
            8, this_._internal_roles_sid(), byte_size, target);
      }
    }
  }

  // repeated sint64 memids = 9 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    {
      int byte_size = this_._impl_._memids_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteSInt64Packed(
            9, this_._internal_memids(), byte_size, target);
      }
    }
  }

  // repeated .OSMPBF.Relation.MemberType types = 10 [packed = true];
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    {
      ::size_t byte_size = this_._impl_._types_cached_byte_size_.Get();
      if (byte_size > 0) {
        target = stream->WriteEnumPacked(
            10, this_._internal_types(), byte_size, target);
      }
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target = stream->WriteRaw(
        this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).data(),
        static_cast<int>(this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:OSMPBF.Relation)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Relation::ByteSizeLong(const MessageLite& base) {
  const Relation& this_ = static_cast<const Relation&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Relation::ByteSizeLong() const {
  const Relation& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:OSMPBF.Relation)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // repeated uint32 keys = 2 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          ::_pbi::WireFormatLite::UInt32SizeWithPackedTagSize(
              this_._internal_keys(), 1,
              this_._impl_._keys_cached_byte_size_);
    }
    // repeated uint32 vals = 3 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size +=
          ::_pbi::WireFormatLite::UInt32SizeWithPackedTagSize(
              this_._internal_vals(), 1,
              this_._impl_._vals_cached_byte_size_);
    }
    // repeated int32 roles_sid = 8 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size +=
          ::_pbi::WireFormatLite::Int32SizeWithPackedTagSize(
              this_._internal_roles_sid(), 1,
              this_._impl_._roles_sid_cached_byte_size_);
    }
    // optional .OSMPBF.Info info = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.info_);
    }
  }
   {
    // required int64 id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
          this_._internal_id());
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000060U)) {
    // repeated sint64 memids = 9 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size +=
          ::_pbi::WireFormatLite::SInt64SizeWithPackedTagSize(
              this_._internal_memids(), 1,
              this_._impl_._memids_cached_byte_size_);
    }
    // repeated .OSMPBF.Relation.MemberType types = 10 [packed = true];
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      total_size += ::_pbi::WireFormatLite::EnumSizeWithPackedTagSize(
          this_._internal_types(), 1, this_._impl_._types_cached_byte_size_);
    }
  }
  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    total_size += this_._internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString).size();
  }
  this_._impl_._cached_size_.Set(::_pbi::ToCachedSize(total_size));
  return total_size;
}

void Relation::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Relation*>(&to_msg);
  auto& from = static_cast<const Relation&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:OSMPBF.Relation)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_keys()->MergeFrom(from._internal_keys());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_vals()->MergeFrom(from._internal_vals());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_mutable_roles_sid()->MergeFrom(from._internal_roles_sid());
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.info_ != nullptr);
      if (_this->_impl_.info_ == nullptr) {
        _this->_impl_.info_ = ::google::protobuf::MessageLite::CopyConstruct(arena, *from._impl_.info_);
      } else {
        _this->_impl_.info_->MergeFrom(*from._impl_.info_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_impl_.id_ = from._impl_.id_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_internal_mutable_memids()->MergeFrom(from._internal_memids());
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _this->_internal_mutable_types()->MergeFrom(from._internal_types());
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::std::string>(
      from._internal_metadata_);
}

void Relation::CopyFrom(const Relation& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:OSMPBF.Relation)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool Relation::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const Relation&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void Relation::InternalSwap(Relation* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.keys_.InternalSwap(&other->_impl_.keys_);
  _impl_.vals_.InternalSwap(&other->_impl_.vals_);
  _impl_.roles_sid_.InternalSwap(&other->_impl_.roles_sid_);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Relation, _impl_.id_)
      + sizeof(Relation::_impl_.id_)
      - PROTOBUF_FIELD_OFFSET(Relation, _impl_.info_)>(
          reinterpret_cast<char*>(&_impl_.info_),
          reinterpret_cast<char*>(&other->_impl_.info_));
  _impl_.memids_.InternalSwap(&other->_impl_.memids_);
  _impl_.types_.InternalSwap(&other->_impl_.types_);
}

// @@protoc_insertion_point(namespace_scope)
}  // namespace OSMPBF
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
#include "google/protobuf/port_undef.inc"
